# Lances-vous !

Bienvenue chez Rapunzel, un environnement de développement moderne pour Python et R. Voici quelques raccourcis clavier pratiques.


## Utiliser des dossiers et fichiers de projet

- [`Ctrl+Shift+O`: Ouvrir un dossier de projet](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: Ouvrir un fichier à partir des dossiers de projet](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: Créer un nouveau document](opensesame://event.ide_new_file)


## Faire les choses rapidement

- [`Ctrl+Shift+P`: Activer la palette du commande](opensesame://event.command_palette_activate)
- `Ctrl+R`: Accéder au fonction ou class


## Exécuter du code

- `F5`: Exécuter le projet ou le fichier
- `F9`: Exécuter la sélection, la cellule ou la ligne actuelle
